## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",
  eval = FALSE
)

## -----------------------------------------------------------------------------
# library(shiny)
# library(shinyglass)
# 
# ui <- fluidPage(
#   theme = glass_theme(), # or preset = "dark" / "auto"
#   titlePanel("Liquid Glass"),
#   plotOutput("p")
# )

## -----------------------------------------------------------------------------
# ui <- fluidPage(
#   theme = glass_theme(preset = "auto"),
#   glass_theme_toggle(selected = "auto"),
#   selectInput("accent", "Accent", c(
#     Blue = "#007AFF", Purple = "#AF52DE", Orange = "#FF9500"
#   ))
# )
# 
# server <- function(input, output, session) {
#   observe_glass_theme_toggle(input, session)
#   observeEvent(input$accent, {
#     update_glass_theme(session, primary = input$accent)
#   }, ignoreInit = TRUE)
# }

## -----------------------------------------------------------------------------
# ui <- fluidPage(
#   theme = glass_theme(preset = "auto"),
#   glass_theme_toggle(),           # Light / Dark / Auto buttons
#   # ...
# )
# 
# server <- function(input, output, session) {
#   observe_glass_theme_toggle(input, session)
# }

## -----------------------------------------------------------------------------
# glass_theme(
#   preset = "auto",
#   primary = "#AF52DE",
#   blur = 36,
#   saturation = 200,
#   radius = "1.5rem",
#   material = "regular", # or "clear" over media-rich content
#   intensity = 0.45,     # 0 Ultra Clear → 1 Tinted (iOS 27)
#   tint = TRUE,      # sample plot/image colors into glass surfaces
#   specular = TRUE,  # pointer specular highlight
#   nav_morph = TRUE  # compact navbar while scrolling down
# )

## -----------------------------------------------------------------------------
# glass_intensity_slider("glass_intensity", value = 0.45)

## -----------------------------------------------------------------------------
# options(teal.bs_theme = glass_theme(preset = "auto"))
# # then teal::init(...) as usual

